summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2024-02-08 00:27:29 +0100
committerChristian Grothoff <christian@grothoff.org>2024-02-08 00:27:29 +0100
commit82c39b7dd858e0271846ee5e0f8386a44d9a6131 (patch)
treed9f7e8915ca650f2ce2327f7b54d0014d242b386 /src
parent9eeccf18a55705f67c79f536c9e4af1825d2eaac (diff)
downloadexchange-82c39b7dd858e0271846ee5e0f8386a44d9a6131.tar.gz
exchange-82c39b7dd858e0271846ee5e0f8386a44d9a6131.tar.bz2
exchange-82c39b7dd858e0271846ee5e0f8386a44d9a6131.zip
-doxygen fixes
Diffstat (limited to 'src')
-rw-r--r--src/auditordb/pg_update_balance.h2
-rw-r--r--src/include/taler_auditordb_plugin.h4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/auditordb/pg_update_balance.h b/src/auditordb/pg_update_balance.h
index 6a4ee04b5..8f83726f5 100644
--- a/src/auditordb/pg_update_balance.h
+++ b/src/auditordb/pg_update_balance.h
@@ -32,7 +32,7 @@
*
* @param cls the @e cls of this struct with the plugin-specific state
* @param balance_key key of the balance to store
- * @param balance_value value to store
+ * @param balance_amount value to store
* @param ... NULL terminated list of additional key-value pairs to update
* @return transaction status code
*/
diff --git a/src/include/taler_auditordb_plugin.h b/src/include/taler_auditordb_plugin.h
index ac32cf3b9..c0a771343 100644
--- a/src/include/taler_auditordb_plugin.h
+++ b/src/include/taler_auditordb_plugin.h
@@ -548,14 +548,14 @@ struct TALER_AUDITORDB_Plugin
*
* @param cls the @e cls of this struct with the plugin-specific state
* @param balance_key key of the balance to store
* @param balance_value value to store
* @param ... NULL terminated list of additional key-value pairs to update
* @return transaction status code
*/
enum GNUNET_DB_QueryStatus
(*update_balance)(void *cls,
const char *balance_key,
- const struct TALER_Amount *balance_value,
+ const struct TALER_Amount *balance_amount,
...);
@@ -548,14 +548,14 @@ struct TALER_AUDITORDB_Plugin
* @param cls the @e cls of this struct with the plugin-specific state
* @param balance_key key of the balance to store
- * @param balance_value value to store
+ * @param balance_amount value to store
* @param ... NULL terminated list of additional key-value pairs to update
* @return transaction status code